<?php

namespace Mbl\MblUsersExport;

use Exception;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

class FilterMembers
{
    const FILE_NAME = 'users.xlsx';
    public $includeIds;
    public $excludeIds;
    public $date;
    public $datePeriod;
    public $active;
    /**
     * @var mixed|string
     * 'date_start' or 'date_end'
     */
    public $wpmLevel;

    public function __construct(
        $include = [],
        $exclude = [],
        $date = '',
        $datePeriod = '',
        $wpmLevel = 'date_start',
        $active = 1
    )
    {
        $this->includeIds = $include;
        $this->excludeIds = $exclude;
        $this->date = $date;
        $this->datePeriod = $datePeriod;
        $this->wpmLevel = $wpmLevel;
        $this->active = $active;
    }

    public function getMembers(): array
    {
        global $wpdb;
        if (
            (empty($this->includeIds) && empty($this->excludeIds))
            || count(array_intersect($this->includeIds, $this->excludeIds)) > 0
        ) {
            $user_ids = [];
        } else {
            $select = "SELECT ID FROM {$wpdb->users} as u";
            $where = "1";
            if (!empty($this->includeIds)) {
                $includeAsString = implode(', ', $this->includeIds);
                $subWhere = "";
                if (!empty($this->date)) {
                    $sign = $this->datePeriod === 'before' ? '<' : '>';
                    $subWhere .= " AND `$this->wpmLevel` $sign '$this->date'";
                }
                $where .= " AND (SELECT COUNT(*) FROM {$wpdb->prefix}memberlux_term_keys
                    WHERE user_id = u.ID AND term_id IN ($includeAsString) $subWhere
                 ) > 0";
            }
            if (!empty($this->excludeIds)) {
                $excludeAsString = implode(', ', $this->excludeIds);
                $where .= " AND (SELECT COUNT(*) FROM {$wpdb->prefix}memberlux_term_keys
                    WHERE user_id = u.ID AND term_id IN ($excludeAsString)
                ) = 0";
            }
            $user_ids = $wpdb->get_col("$select WHERE $where");
        }

        return Member::getMembersDataByIds($user_ids, $this->active);
    }

    public function excludeUserWhere(): string
    {
        global $wpdb;
        $where = '';
        if (!empty($this->excludeIds)) {

            $excludeAsString = implode(', ', $this->excludeIds);
            $excludeSql = "SELECT DISTINCT user_id
                FROM $wpdb->users AS users
                LEFT JOIN {$wpdb->prefix}memberlux_term_keys AS term_keys ON users.ID = term_keys.user_id
            ";
            $excludeWhere = "user_id != 'NULL' AND term_id NOT IN ($excludeAsString)";
            $exclude_user_ids = $wpdb->get_col("$excludeSql WHERE $excludeWhere");
            if (!empty($exclude_user_ids)) {
                $where = ' AND user_id NOT IN (' . implode(', ', $exclude_user_ids) . ')';
            }
        }

        return $where;
    }

    public static function saveUserIds($ids): string
    {
        if (!is_dir(dirname(__DIR__) . '/temp')) {
            mkdir(dirname(__DIR__) . '/temp');
        }
        file_put_contents(dirname(__DIR__) . '/temp/filter-ids.json', json_encode($ids));
        return plugin_dir_url(dirname(__DIR__) . '/excelGenerator.php') . 'excelGenerator.php';
    }

    public static function getExcelFile()
    {
        $ids = explode(',', json_decode(file_get_contents(dirname(__DIR__) . '/temp/filter-ids.json')));
        $spreadsheet = new Spreadsheet();
        try {
            $sheet = $spreadsheet->getActiveSheet();;
            foreach (['A', 'B', 'C', 'D', 'E', 'F', 'G'] as $heading) {
                $sheet->getColumnDimension($heading)->setAutoSize(true);
            }
            $users = Member::getMembersDataByIds($ids);
            $data = [['ID', 'Логин', 'Фамилия', 'Имя', 'Отчество', 'Телефон', 'Email']];
            foreach ($users as $user) {
                $data[] = [$user['ID'], $user['userName'], $user['lastName'], $user['firstName'], $user['surname'],
                    $user['phone'], $user['email']];
            }
            $sheet->fromArray($data);

            $writer = new Xlsx($spreadsheet);
            $writer->save('php://output');
        } catch (Exception $error) {
            var_dump($error->getMessage());
        }
    }
}
