<?php

namespace Mbl\MblUsersExport;

class Member
{
    public static function getMembersByFio(
        string $last_name,
        string $first_name,
        string $surname = '',
               $fields = 'all'
    ): array
    {
        $meta_query = [
            'relation' => 'AND',
            [
                'key' => 'first_name',
                'value' => $first_name
            ],
            [
                'key' => 'last_name',
                'value' => $last_name
            ],
        ];
        if (!empty($surname)) {
            $meta_query[] = [
                'key' => 'surname',
                'value' => $surname
            ];
        }
        return get_users([
            'meta_query' => $meta_query,
            'fields' => $fields
        ]);
    }

    /**
     * Возвращает массив данных отфильтрованных пользователей
     * @param $ids int[]
     * @return array []
     */
    public static function getMembersDataByIds(array $ids, $active = false): array
    {
        $users = [];
        if (!empty($ids)) {
            $args = ['include' => $ids, 'role' => 'customer',];
            if ($active) {
                $args['meta_query'] = [
                    'relation' => 'OR',
                    [
                        'key' => 'wpm_status',
                        'value' => 'inactive',
                        'compare' => '!=',
                    ],
                    [
                        'key' => 'wpm_status',
                        'compare' => 'NOT EXISTS',
                    ]
                ];
            }
            $usersObj = get_users($args);
            foreach ($usersObj as $user) {
                $users[] = [
                    'ID' => $user->ID,
                    'userName' => $user->user_login,
                    'userLink' => admin_url('user-edit.php') . '?' . http_build_query(['user_id' => $user->ID]),
                    'lastName' => $user->last_name,
                    'firstName' => $user->user_firstname,
                    'surname' => get_user_meta($user->ID, 'surname', true),
                    'phone' => get_user_meta($user->ID, 'phone', 1),
                    'email' => $user->user_email,
                ];
            }
        }

        return $users;
    }
}
